==> ovenmediaengine-0.15.16-1-x86_64.pkg.tar.zst: usr/share/doc/ovenmediaengine/quick-start/test-player.md <==
# Online Demo

## Player & WebRTC Encoder

We provide online demos of OvenPlayer(WebRTC/LLHLS Player) and OvenLiveKit(WebRTC Live Encoder) so that users can easily test out OvenMediaEngine.

{% hint style="warning" %}
To connect to your OvenMediaEngine in the online demo, you will need to install a certificate and use either the HTTPS or WSS protocol. Unsecured HTTP or WS protocols could not work in online demos due to browser security policies.
{% endhint %}

| Site URL                                                                                     | Description                            |
| -------------------------------------------------------------------------------------------- | -------------------------------------- |
| [http://demo.ovenplayer.com](http://demo.ovenplayer.com)                                     | OvenPlayer demo (TLS not enabled)      |
| [https://demo.ovenplayer.com](https://demo.ovenplayer.com)                                   | OvenPlayer demo                        |
| [https://demo.ovenplayer.com/demo\_input.html](https://demo.ovenplayer.com/demo\_input.html) | OvenLiveKit (WebRTC Live Encoder) demo |

## OvenSpace

OvenSpace offers a fast and easy way to experience the powerful tools of OvenMediaEngine, OvenPlayer, and OvenLiveKit in action.

With OvenSpace, you can quickly and easily stream content with sub-second latency using WebRTC technology, or take advantage of Apple's LLHLS specification to deliver low-latency live streaming. The platform allows you to stream from various sources, including your webcam, microphone, screen, or an external live encoder that supports RTMP and SRT.

OvenSpace is available online, so you can try it out for yourself at [https://space.ovenplayer.com/](https://space.ovenplayer.com/). You'll get a hands-on experience of how OvenMediaEngine, OvenPlayer, and OvenLiveKit work together seamlessly to deliver top-quality streaming, whether you're a developer looking to build a media service or someone who wants to experience sub-second or low-latency streaming firsthand.

OvenSpace is also available on [Github](https://github.com/AirenSoft/OvenSpace) as open source. It will be a good reference when developing media services using OvenMediaEngine, OvenPlayer and OvenLiveKit.

<figure><img src="../https://raw.githubusercontent.com/AirenSoft/OvenMediaEngine/v0.15.16/docs/.gitbook/assets/image (6).png" alt=""><figcaption><p><a href="https://space.ovenplayer.com/">https://space.ovenplayer.com/</a></p></figcaption></figure>

==> ovenmediaengine-0.16.8-1-x86_64.pkg.tar.zst: usr/share/doc/ovenmediaengine/quick-start/test-player.md <==
# Online Demo

## Player & WebRTC Encoder

We provide online demos of OvenPlayer(WebRTC/LLHLS Player) and OvenLiveKit(WebRTC Live Encoder) so that users can easily test out OvenMediaEngine.

{% hint style="warning" %}
To connect to your OvenMediaEngine in the online demo, you will need to install a certificate and use either the HTTPS or WSS protocol. Unsecured HTTP or WS protocols could not work in online demos due to browser security policies.
{% endhint %}

<table data-header-hidden><thead><tr><th width="412">Site URL</th><th>Description</th></tr></thead><tbody><tr><td>Site URL</td><td>Description</td></tr><tr><td><a href="http://demo.ovenplayer.com">http://demo.ovenplayer.com</a></td><td>OvenPlayer demo (TLS not enabled)</td></tr><tr><td><a href="https://demo.ovenplayer.com">https://demo.ovenplayer.com</a></td><td>OvenPlayer demo</td></tr><tr><td><a href="https://demo.ovenplayer.com/demo_input.html">https://demo.ovenplayer.com/demo_input.html</a></td><td>OvenLiveKit (WebRTC Live Encoder) demo</td></tr></tbody></table>

## OvenSpace

OvenSpace offers a fast and easy way to experience the powerful tools of OvenMediaEngine, OvenPlayer, and OvenLiveKit in action.

With OvenSpace, you can quickly and easily stream content with sub-second latency using WebRTC technology, or take advantage of Apple's LLHLS specification to deliver low-latency live streaming. The platform allows you to stream from various sources, including your webcam, microphone, screen, or an external live encoder that supports RTMP and SRT.

OvenSpace is available online, so you can try it out for yourself at [https://space.ovenplayer.com/](https://space.ovenplayer.com/). You'll get a hands-on experience of how OvenMediaEngine, OvenPlayer, and OvenLiveKit work together seamlessly to deliver top-quality streaming, whether you're a developer looking to build a media service or someone who wants to experience sub-second or low-latency streaming firsthand.

OvenSpace is also available on [Github](https://github.com/AirenSoft/OvenSpace) as open source. It will be a good reference when developing media services using OvenMediaEngine, OvenPlayer and OvenLiveKit.

<figure><img src="../https://raw.githubusercontent.com/AirenSoft/OvenMediaEngine/v0.16.8/docs/.gitbook/assets/image (6).png" alt=""><figcaption><p><a href="https://space.ovenplayer.com/">https://space.ovenplayer.com/</a></p></figcaption></figure>
